==> geeklog-1.5.1-jp-extended-1.0.zip: geeklog-1.5.1-jp-extended-1.0/plugins/nmoxtopicown/language/english_utf-8.php <==
<?php

// +---------------------------------------------------------------------------+
// | nmoxtopicown Geeklog Plugin 1.0                                       |
// +---------------------------------------------------------------------------+
// | english_utf-8.php                                                         |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007 by nmox                                                |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// +---------------------------------------------------------------------------+
// | Array Format:                                                             |
// | $LANGXX[YY]:	$LANG - variable name                                      |
// |	  	XX - file id number                                                |
// |		YY - phrase id number                                              |
// +---------------------------------------------------------------------------+

/**
* Generic Install language
* 
* Be sure and change the name of this array to match your plugin
* e.g. $LANG_ST00
*
*/

$LANG_NMOXTOPICOWN= array (
'plugin'				=> 'nmoxtopicown',
'access_denied'			=> 'Access Denied',
'access_denied_msg'		=> 'Only Root Users have Access to this Page.  Your user name and IP have been recorded.',
'install_header'		=> 'Install/Uninstall Plugin',
'installed'				=> 'The Plugin is Installed',
'uninstalled'			=> 'The Plugin is Not Installed',
'install_success'		=> 'Installation Successful',
'install_failed'		=> 'Installation Failed -- See your error log to find out why.',
'uninstall_msg'			=> 'Plugin Successfully Uninstalled',
'install'				=> 'Install',
'uninstall'				=> 'UnInstall',
'ok'					=> 'ok',
'message_caution'		=> '* you will change owner of topic with included all stories.',
'change_writer'			=> 'change writer all stories in this topic.',
'done'					=> 'done'
);
?>

==> geeklog-1.7.0-jp-extended-1.1.zip: geeklog-1.7.0-jp-extended-1.1/plugins/nmoxtopicown/language/english_utf-8.php <==
<?php

// +---------------------------------------------------------------------------+
// | nmoxtopicown Geeklog Plugin 1.0                                           |
// +---------------------------------------------------------------------------+
// | english_utf-8.php                                                         |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007 by nmox                                                |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// +---------------------------------------------------------------------------+
// | Array Format:                                                             |
// | $LANGXX[YY]:	$LANG - variable name                                      |
// |	  	XX - file id number                                                |
// |		YY - phrase id number                                              |
// +---------------------------------------------------------------------------+

/**
* Generic Install language
* 
* Be sure and change the name of this array to match your plugin
* e.g. $LANG_ST00
*
*/

$LANG_NMOXTOPICOWN= array (
'nmoxtopicown'			=> 'NmoxTopicOwn',
'plugin'				=> 'nmoxtopicown',
'access_denied'			=> 'Access Denied',
'access_denied_msg'		=> 'Only Root Users have Access to this Page.  Your user name and IP have been recorded.',
'install_header'		=> 'Install/Uninstall Plugin',
'installed'				=> 'The Plugin is Installed',
'uninstalled'			=> 'The Plugin is Not Installed',
'install_success'		=> 'Installation Successful',
'install_failed'		=> 'Installation Failed -- See your error log to find out why.',
'uninstall_msg'			=> 'Plugin Successfully Uninstalled',
'install'				=> 'Install',
'uninstall'				=> 'UnInstall',
'ok'					=> 'OK',
'message_caution'		=> '* You will change owner of topic with included all stories.',
'change_writer'			=> 'Change writer all stories in this topic.',
'done'					=> 'Done'
);
?>
